import { http } from "@/utils/http";
import type {
  VersionInfo,
  GetVersionListParams,
  AddVersionParams,
  UpdateVersionParams,
  ImportHtsItem
} from "types/hts";
import type {
  HtsClassInfo,
  GetHtsClassListParams,
  AddHtsClassParams,
  UpdateHtsClassParams
} from "types/hts";
import type {
  HtsItemInfo,
  GetHtsItemListParams,
  AddHtsItemParams,
  UpdateHtsItemParams
} from "types/hts";
import { filterEmptyObject } from "./utils";

/** 添加税率编码版本数据 */
export const postAddVersionAPI = (data: AddVersionParams) => {
  return http.request<null>("post", "/api/hts/version/add", { data });
};

/** 删除税率编码版本数据 */
export const deleteVersionAPI = (id: string) => {
  return http.request<null>("delete", `/api/hts/version/delete/${id}`);
};

/** 批量删除税率编码版本数据 */
export const deleteVersionListAPI = (ids: string[]) => {
  return http.request<null>("delete", "/api/hts/version/delete", {
    data: { ids }
  });
};

/** 修改税率编码版本数据 */
export const putUpdateVersionAPI = (data: UpdateVersionParams, id: string) => {
  return http.request<null>("put", `/api/hts/version/update/${id}`, { data });
};

/** 获取税率编码版本信息 */
export const getVersionInfoAPI = (id: string) => {
  return http.request<VersionInfo>("get", `/api/hts/version/info/${id}`);
};

/** 获取税率编码版本列表 */
export const getVersionListAPI = (params: GetVersionListParams) => {
  return http.request<QueryListResult<VersionInfo>>(
    "get",
    "/api/hts/version/list",
    {
      params: filterEmptyObject(params)
    }
  );
};

/** 添加编码类别数据 */
export const postAddHtsClassAPI = (data: AddHtsClassParams) => {
  return http.request<null>("post", "/api/hts/class/add", { data });
};

/** 删除编码类别数据 */
export const deleteHtsClassAPI = (id: string) => {
  return http.request<null>("delete", `/api/hts/class/delete/${id}`);
};

/** 批量删除编码类别数据 */
export const deleteHtsClassListAPI = (ids: string[]) => {
  return http.request<null>("delete", "/api/hts/class/delete", {
    data: { ids }
  });
};

/** 修改编码类别数据 */
export const putUpdateHtsClassAPI = (
  data: UpdateHtsClassParams,
  id: string
) => {
  return http.request<null>("put", `/api/hts/class/update/${id}`, { data });
};

/** 获取编码类别信息 */
export const getHtsClassInfoAPI = (id: string) => {
  return http.request<HtsClassInfo>("get", `/api/hts/class/info/${id}`);
};

/** 获取编码类别列表 */
export const getHtsClassListAPI = (params: GetHtsClassListParams) => {
  return http.request<QueryListResult<HtsClassInfo>>(
    "get",
    "/api/hts/class/list",
    {
      params: filterEmptyObject(params)
    }
  );
};

/** 添加编码项数据 */
export const postAddHtsItemAPI = (data: AddHtsItemParams) => {
  return http.request<null>("post", "/api/hts/item/add", { data });
};

/** 删除编码项数据 */
export const deleteHtsItemAPI = (id: string) => {
  return http.request<null>("delete", `/api/hts/item/delete/${id}`);
};

/** 批量删除编码项数据 */
export const deleteHtsItemListAPI = (ids: string[]) => {
  return http.request<null>("delete", "/api/hts/item/delete", {
    data: { ids }
  });
};

/** 修改编码项数据 */
export const putUpdateHtsItemAPI = (data: UpdateHtsItemParams, id: string) => {
  return http.request<null>("put", `/api/hts/item/update/${id}`, { data });
};

/** 获取编码项信息 */
export const getHtsItemInfoAPI = (id: string) => {
  return http.request<HtsItemInfo>("get", `/api/hts/item/info/${id}`);
};

/** 获取编码项列表 */
export const getHtsItemListAPI = (params: GetHtsItemListParams) => {
  return http.request<QueryListResult<HtsItemInfo>>(
    "get",
    "/api/hts/item/list",
    {
      params: filterEmptyObject(params)
    }
  );
};

/**导入编码项 */
export const postImportHtsItemAPI = (data: ImportHtsItem) => {
  return http.request<null>("POST", "/api/hts/item/import", { data });
};
