/** 税率编码版本信息 */
export interface VersionInfo {
  /** 主键 */
  id: string;

  /** 创建时间 */
  create_time: string;

  /** 更新时间 */
  update_time: string;

  /** 版本号 */
  version: string;

  /** 版本日期 */
  date: any;

  /** 下载地址 */
  url: string;
}

/** 获取税率编码版本列表参数 */
export interface GetVersionListParams {
  /** 当前页 */
  page: number;

  /** 每页数量 */
  pageSize: number;

  /** 版本号 */
  version?: string;

  /** 版本日期 */
  date?: string;

  /** 下载地址 */
  url?: string;
}

/** 添加税率编码版本数据参数 */
export interface AddVersionParams {
  /** 版本号 */
  version: string;

  /** 版本日期 */
  date: string;

  /** 下载地址 */
  url: string;
}

/** 更新税率编码版本数据参数 */
export interface UpdateVersionParams {
  /** 版本号 */
  version: string;

  /** 版本日期 */
  date: string;

  /** 下载地址 */
  url: string;
}

/** 编码类别信息 */
export interface HtsClassInfo {
  /** 主键 */
  id: string;

  /** 创建时间 */
  create_time: string;

  /** 更新时间 */
  update_time: string;

  /** 类名 */
  class_name: string;

  /** 类描述 */
  class_description: string;

  /** 章节 */
  chapter_name: string;

  /** 章节描述 */
  chapter_description: string;
}

/** 获取编码类别列表参数 */
export interface GetHtsClassListParams {
  /** 当前页 */
  page: number;

  /** 每页数量 */
  pageSize: number;

  /** 类名 */
  class_name?: string;

  /** 类描述 */
  class_description?: string;

  /** 章节 */
  chapter_name?: string;

  /** 章节描述 */
  chapter_description?: string;
}

/** 添加编码类别数据参数 */
export interface AddHtsClassParams {
  /** 类名 */
  class_name: string;

  /** 类描述 */
  class_description: string;

  /** 章节 */
  chapter_name: string;

  /** 章节描述 */
  chapter_description: string;
}

/** 更新编码类别数据参数 */
export interface UpdateHtsClassParams {
  /** 类名 */
  class_name: string;

  /** 类描述 */
  class_description: string;

  /** 章节 */
  chapter_name: string;

  /** 章节描述 */
  chapter_description: string;
}

/** 编码项目信息 */
export interface HtsItemInfo {
  /** 主键 */
  id: string;

  /** 创建时间 */
  create_time: string;

  /** 更新时间 */
  update_time: string;

  /** 父编码 */
  parent_id: string;

  /** 编码 */
  htsno: string;

  /** 层级 */
  indent: number | string;

  /** 描述 */
  description: string;

  /** 单位列表 */
  units: any;

  /** 通用税率 */
  general: string;

  /** 特殊税率，适用于特定国家或地区 */
  special: string;

  /** 其他税率 */
  other: string;

  /** 配额数量 */
  quota_quantity: string;

  /** 附加税 */
  additional_duties: string;

  /** 脚注列表 */
  footnotes: any;

  /** 所属类 */
  class_id: string;

  /** 所属版本 */
  version_id: string;
}

/** 获取编码项目列表参数 */
export interface GetHtsItemListParams {
  /** 当前页 */
  page: number;

  /** 每页数量 */
  pageSize: number;

  /** 编码 */
  htsno?: string;

  /** 描述 */
  description?: string;

  /** 单位列表 */
  units?: string;

  /** 通用税率 */
  general?: string;

  /** 特殊税率，适用于特定国家或地区 */
  special?: string;

  /** 其他税率 */
  other?: string;

  /** 配额数量 */
  quota_quantity?: string;

  /** 附加税 */
  additional_duties?: string;

  /** 脚注列表 */
  footnotes?: string;

  /** 所属类 */
  class_id?: string;

  /** 所属版本 */
  version_id?: string;
}

/** 添加编码项目数据参数 */
export interface AddHtsItemParams {
  /** 父编码 */
  parent_id?: string;

  /** 编码 */
  htsno: string;

  /** 层级 */
  indent: number;

  /** 描述 */
  description: string;

  /** 单位列表 */
  units: any;

  /** 通用税率 */
  general: string;

  /** 特殊税率，适用于特定国家或地区 */
  special: string;

  /** 其他税率 */
  other: string;

  /** 配额数量 */
  quota_quantity: string;

  /** 附加税 */
  additional_duties: string;

  /** 脚注列表 */
  footnotes: any;

  /** 所属类 */
  class_id: string;

  /** 所属版本 */
  version_id: string;
}

/** 更新编码项目数据参数 */
export interface UpdateHtsItemParams {
  /** 父编码 */
  parent_id?: string;

  /** 编码 */
  htsno: string;

  /** 层级 */
  indent: number;

  /** 描述 */
  description: string;

  /** 单位列表 */
  units: any;

  /** 通用税率 */
  general: string;

  /** 特殊税率，适用于特定国家或地区 */
  special: string;

  /** 其他税率 */
  other: string;

  /** 配额数量 */
  quota_quantity: string;

  /** 附加税 */
  additional_duties: string;

  /** 脚注列表 */
  footnotes: any;

  /** 所属类 */
  class_id: string;

  /** 所属版本 */
  version_id: string;
}

/**导入编码项 */
export interface ImportHtsItem {
  file_id: string;
  version_id: string;
  class_id: string;
}

export interface CodeHtsInfo {
  oneResult: HtsItemInfo;
  secondResult: HtsItemInfo;
  threeResult: HtsItemInfo;
  fourResult: HtsItemInfo;
  fiveResult: HtsItemInfo;
}
